# Running Models 

## Overview

To run specific models, each folder contains a
Makefile that can simply be run inside a specific model folder.
The workflow includes running WolframScript to generate matrix elements, using Python to generate collision data, and finally processing the data with the main Python script.

## Directory Structure

- `MatrixElements/` - Contains the script and data files for matrix element generation.
- `CollisionOutput/` - Directory where collision data files are stored.


## Makefile Targets

### `all`

This is the default target which runs the `model` target.

### `generateMatrixElements`
Generates matrix Elements at `MatrixElements.txt` from
`MatrixElements/<Model>.m`
as sometimes only the matrix elements need to be generated.

### `model`
Runs only the model file
`<model-name>.py`
as sometimes no new matrix elements or collision integrals need to be generated.

### `generate_collisions`

Generates collision data files using the matrix elements. This target depends on `MatrixElements.txt`, which is generated by running a WolframScript file.

### `clean`

Removes the `CollisionOutput` and `MatrixElements` directories and all their contents.

## Dependencies

- `python3` - Required for running Python scripts.
- `wolframscript` - Required for running the WolframScript file to generate matrix elements.


- `matrixElements.m` -
    MatrixElement script based on DRalgo.
    See [https://github.com/Wall-Go/MatrixElements](https://github.com/Wall-Go/MatrixElements). 
- `DRalgo` - See [https://github.com/DR-algo/DRalgo](https://github.com/DR-algo/DRalgo).

Both `matrixElements.m` and the `DRalgo` folder should be placed in a directory visible to Mathematica. The best options are to place it in the Applications subfolder of
`$BaseDirectory` or `$UserBaseDirectory`.
Often, the paths are the following:

### For Linux

    /usr/share/Mathematica/Applications
    /home/<computer-name>/.Mathematica/Applications

### For Windows

    C:\ProgramData\Mathematica\Applications
    C:\Users\<computer-name>\AppData\Roaming\Mathematica\Applications

## Usage

### Full pipeline
1. **Generate Collisions**:
    Ensure that the matrix elements data file `MatrixElements.txt` exists, then generate collision data by running:
   ```sh
   make generate_collisions
   ```

2. **Run Main (Model) Script**:
    Once collision data files are generated, run the main Python script:
   ```sh
   make model
   ```

4. **Clean Up**:
    To clean up the generated collision data files and matrix elements:
   ```sh
   make clean
   ```

### Matrix Elements
1. **Generate Matrix Elements**:
    In that case it suffices to run:
   ```sh
   make generateMatrixElements
   ```

## File Descriptions

- `MatrixElements/matrixElements.qcd.m` - WolframScript file for generating matrix elements.
- `MatrixElements.txt` - Output data file containing matrix elements.
- `collisionGenerator.py` - Python script for generating collision data.
- `<model-name>.py` - Main Python Model script that uses the collision data e.g. `SingletStandardModel_Z2.py`

## Notes

- Ensure that the necessary Python and WolframScript dependencies are installed and properly configured in your environment.
- The `CollisionOutput` directory is automatically created if it does not exist when running the `generate_collisions` target.